/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser.test.clazz.group;

import com.liferay.jenkins.results.parser.JenkinsResultsParserUtil;
import com.liferay.jenkins.results.parser.PortalGitWorkingDirectory;
import com.liferay.jenkins.results.parser.PortalTestClassJob;

import java.io.File;
import java.io.IOException;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Leslie Wong
 */
public class ModulesCompileBatchTestClassGroup extends BatchTestClassGroup {

	public static class ModulesCompileBatchTestClass extends BaseTestClass {

		protected static ModulesCompileBatchTestClass getInstance(
			String batchName, File moduleBaseDir) {

			return new ModulesCompileBatchTestClass(batchName, moduleBaseDir);
		}

		protected ModulesCompileBatchTestClass(
			String batchName, File moduleBaseDir) {

			super(moduleBaseDir);

			addTestMethod(batchName);
		}

	}

	protected ModulesCompileBatchTestClassGroup(
		String batchName, PortalTestClassJob portalTestClassJob) {

		super(batchName, portalTestClassJob);

		try {
			excludesPathMatchers.addAll(
				getPathMatchers(
					getFirstPropertyValue("modules.excludes"),
					portalGitWorkingDirectory.getWorkingDirectory()));

			includesPathMatchers.addAll(
				getPathMatchers(
					getFirstPropertyValue("modules.includes"),
					portalGitWorkingDirectory.getWorkingDirectory()));

			setTestClasses();

			setAxisTestClassGroups();
		}
		catch (IOException ioe) {
			throw new RuntimeException(ioe);
		}
	}

	protected void setTestClasses() throws IOException {
		PortalGitWorkingDirectory portalGitWorkingDirectory =
			getPortalGitWorkingDirectory();

		List<File> moduleDirsList = portalGitWorkingDirectory.getModuleDirsList(
			excludesPathMatchers, includesPathMatchers);

		if (testRelevantChanges) {
			moduleDirsList = new ArrayList<>();

			List<File> modifiedModuleDirsList =
				portalGitWorkingDirectory.getModifiedModuleDirsList(
					excludesPathMatchers, includesPathMatchers);

			for (File modifiedModuleDir : modifiedModuleDirsList) {
				List<File> lfrBuildPortalFiles =
					JenkinsResultsParserUtil.findFiles(
						modifiedModuleDir, "\\.lfrbuild-portal");

				if (!lfrBuildPortalFiles.isEmpty()) {
					moduleDirsList.add(modifiedModuleDir);
				}
			}
		}

		for (File moduleDir : moduleDirsList) {
			testClasses.add(
				ModulesCompileBatchTestClass.getInstance(batchName, moduleDir));
		}
	}

}